local K = unpack(select(2, ...))

-- Lua API
local _G = _G
local table_wipe = _G.table.wipe

-- GLOBALS: SkinnerDB

local SkinnerDB = _G.SkinnerDB

function K.LoadSkinnerProfile()
	if SkinnerDB then
		table_wipe(SkinnerDB)
	end

	_G.SkinnerDB["profiles"]["Default"] = {
		-- General
		["Warnings"] = false,
		["Errors"] = false,
		["MinimapIcon"] = {
			["hide"] = true,
			["minimapPos"] = 210,
			["radius"] = 80,
		},
		["DropDownPanels"] = true,
		["DropDownButtons"] = false,
		-- Backdrop Settings
		["BdDefault"] = false,
		["BdDefault"] = false,
		["BdFile"] = "None",
		["BdTexture"] = "Blizzard Dialog Background Dark",
		["BdTileSize"] = 16,
		["BdEdgeFile"] = "None",
		["BdBorderTexture"] = "Blizzard Tooltip",
		["BdEdgeSize"] = 16,
		["BdInset"] = 4,
		["StatusBar"] = {
			["texture"] = "KkthnxUI_StatusBar",
		},
		-- Background Texture settings
		["BgUseTex"] = false,
		["BgFile"] = "None",
		["BgTexture"] = "None",
		["BgTile"] = false,
		["LFGTexture"] = false,
		-- Colours
		["ClassClrBd"] = false,
		["ClassClrBg"] = false,
		["ClassClrGr"] = false,
		["ClassClrTT"] = false,
		["TooltipBorder"] = {
			["r"] = 0.752,
			["g"] = 0.752,
			["b"] = 0.752,
			["a"] = 1,
		},
		["BackdropBorder"] = {
			["r"] = 0.752,
			["g"] = 0.752,
			["b"] = 0.752,
			["a"] = 1,
		},
		["Backdrop"] = {
			["r"] = 0,
			["g"] = 0,
			["b"] = 0,
			["a"] = 0.9,
		},
		["HeadText"] = {
			["r"] = 255/255,
			["g"] = 205/255,
			["b"] = 4/255,
		},
		["BodyText"] = {
			["r"] = 1,
			["g"] = 1,
			["b"] = 1,
		},
		["IgnoredText"] = {
			["r"] = 1,
			["g"] = 1,
			["b"] = 1,
		},
		["GradientMin"] = {
			["r"] = 0.1,
			["g"] = 0.1,
			["b"] = 0.1,
			["a"] = 0,
		},
		["GradientMax"] = {
			["r"] = 0.25,
			["g"] = 0.25,
			["b"] = 0.25,
			["a"] = 1,
		},
		["BagginsBBC"] = {
			["r"] = 0.5,
			["g"] = 0.5,
			["b"] = 0.5,
			["a"] = 1,
		},
		-- Gradient
		["Gradient"] = {
			["char"] = false,
			["npc"] = false,
			["enable"] = false,
			["ui"] = false,
			["skinner"] = false,
		},
		-- Modules
		-- populated below
		-- NPC Frames
		["DisableAllNPC"] = false,
		["AlliedRacesUI"] = true,
		["AuctionUI"] = true,
		["AzeriteRespecUI"] = true,
		["BankFrame"] = false,
		["BarbershopUI"] = true,
		["BlackMarketUI"] = true,
		["FlightMap"] = true,
		["GossipFrame"] = true,
		["GuildRegistrar"] = true,
		["ItemUpgradeUI"] = true,
		["MerchantFrame"] = true,
		["Petition"] = true,
		["PetStableFrame"] = true,
		["QuestChoice"] = true,
		["QuestFrame"] = true,
		["SideDressUpFrame"] = true,
		["Tabard"] = true,
		["TaxiFrame"] = true,
		["TrainerUI"] = true,
		["VoidStorageUI"] = true,
		-- Player Frames
		["DisableAllP"] = false,
		["AchievementUI"] = {
			["skin"] = true,
			["style"] = 2,
		},
		["ArchaeologyUI"] = true,
		["AzeriteUI"] = true,
		["Buffs"] = true,
		["CastingBar"] = {
			["skin"] = false,
			["glaze"] = true,
		},
		["CharacterFrames"] = true,
		["Collections"] = true,
		["CommunitiesUI"] = true,
		["CompactFrames"] = true,
		["ContainerFrames"] = {
			["skin"] = false,
			["fheight"] = 100,
		},
		["DressUpFrame"] = true,
		["EncounterJournal"] = true,
		["EquipmentFlyout"] = true,
		["FriendsFrame"] = true,
		["GuildControlUI"] = true,
		["GuildUI"] = true,
		["GuildInvite"] = true,
		["InspectUI"] = true,
		["ItemSocketingUI"] = true,
		["LookingForGuildUI"] = true,
		["LootFrames"] = {
			["skin"] = false,
			["size"] = 1,
		},
		["LootHistory"] = true,
		["MirrorTimers"] = {
			["skin"] = false,
			["glaze"] = true,
		},
		["ObjectiveTracker"] = {
			["skin"] = false,
			["popups"] = false,
		},
		["OverrideActionBar"] = true,
		["PVPFrame"] = true,
		["QuestMap"] = true,
		["RaidUI"] = true,
		["ReadyCheck"] = true,
		["RolePollPopup"] = true,
		["ScrollOfResurrection"] = true,
		["SpellBookFrame"] = true,
		["StackSplit"] = true,
		["TalentUI"] = true,
		["TradeFrame"] = true,
		["TradeSkillUI"] = true,
		["VehicleMenuBar"] = true,
		-- UI Frames
		["DisableAllUI"] = false,
		["AddonList"] = true,
		["AdventureMap"] = true,
		["AlertFrames"] = true,
		["ArtifactUI"] = true,
		["AutoComplete"] = true,
		["BattlefieldMap"] = {
			["skin"] = true,
			["gloss"] = false,
		},
		["BNFrames"] = false,
		["Calendar"] = true,
		["ChallengesUI"] = true,
		["ChatBubbles"] = false,
		["ChatButtons"] = true,
		["ChatConfig"] = true,
		["ChatEditBox"] = {
			["skin"] = false,
			["style"] = 1,
		},
		["ChatFrames"] = false,
		["ChatMenus"] = false,
		["ChatTabs"] = false,
		["ChatTabsFade"] = true,
		["CinematicFrame"] = true,
		["ClassTrial"] = true,
		["CoinPickup"] = true,
		["Colours"] = true,
		["Console"] = true,
		["Contribution"] = true,
		["CombatLogQBF"] = false,
		["DeathRecap"] = true,
		["DebugTools"] = true,
		["DestinyFrame"] = true,
		["GarrisonUI"] = true,
		["GhostFrame"] = false,
		["GMChatUI"] = true,
		["GMSurveyUI"] = true,
		["GuildBankUI"] = false,
		["HelpFrame"] = true,
		["IslandsPartyPoseUI"] = true,
		["IslandsQueueUI"] = true,
		["ItemText"] = true,
		["LevelUpDisplay"] = true,
		["LossOfControl"] = true,
		["MailFrame"] = true,
		["MainMenuBar"] = {
			["skin"] = false,
			["glazesb"] = false,
			["extraab"] = false,
			["altpowerbar"] = false,
		},
		["MenuFrames"] = true,
		["Minimap"] = {
			["skin"] = false,
			["gloss"] = false,
		},
		["MinimapButtons"] = {
			["skin"] = false,
			["style"] = false,
		},
		["MovePad"] = true,
		["MovieFrame"] = true,
		["Nameplates"] = false,
		["ObliterumUI"] = true,
		["OrderHallUI"] = true,
		["PetBattleUI"] = true,
		["ProductChoiceFrame"] = true,
		["PVEFrame"] = true,
		["QuestMap"] = true,
		["QueueStatusFrame"] = true,
		["RaidFrame"] = true,
		["ScriptErrors"] = true,
		["ScrappingMachineUI"] = true,
		["SplashFrame"] = true,
		["StaticPopups"] = true,
		["TalkingHeadUI"] = false,
		["TimeManager"] = true,
		["Tooltips"] = {
			["skin"] = false,
			["style"] = 1,
			["glazesb"] = false,
			["border"] = 1,
		},
		["Tutorial"] = true,
		["UIWidgets"] = true,
		["UnitPopup"] = true,
		["WarboardUI"] = true,
		["WarfrontsPartyPoseUI"] = true,
		["WorldMap"] = {
			["skin"] = true,
			["size"] = 1,
		},
		["WorldState"] = true,
		["ZoneAbility"] = true,
		-- Disabled Skins
		["DisableAllAS"] = false,
		["DisabledSkins"] = {
			["Details"] = true,
			["Skada"] = true,
		},
	}
end